=========
Changelog
=========

**Note**: The module will return the
version of the currently installed
pygame, rather than the version numbers below
to make it transparent.

Version 0.1
===========

- Initial version.

